@@ -67,7 +67,7 @@ test 'simple user tests' => sub {
         },
         "get hri user"
     );
-    cmp_ok( $result->{password}, 'eq', '{CRYPT}*',
+    cmp_ok( $result->{password}, 'eq', '*',
         "default_value for password is good" );
 
     lives_ok(
@@ -158,6 +158,11 @@ test 'simple user tests' => sub {
         "create user with no password" );
     isa_ok($result, "Interchange6::Schema::Result::User", "User obj");
 
+    # refetch user from DB so that default_value of password is set since
+    # otherwise check_password tests below will pass because password is
+    # undef and *not* because ''/undef are passed to check_password
+    $result = $rset_user->find( $result->id );
+
     ok(!$result->check_password(''), "cannot login with empty password");
     ok(!$result->check_password(undef), "cannot login with undef password");
 
